#
# spec file for package gap-semigroups
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-semigroups
Version:        5.5.0
Release:        2.2
Summary:        GAP: Computing with Semigroups of Transformations and Partial Permutations
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://semigroups.github.io/Semigroups/
#Git-Clone:     https://github.com/semigroups/Semigroups
Source:         https://github.com/semigroups/Semigroups/releases/download/v%version/semigroups-%version.tar.gz
Patch1:         no-avx.patch
BuildRequires:  automake
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  gap-devel >= 4.12.1
BuildRequires:  gap-rpm-devel
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  xz
BuildRequires:  pkgconfig(libsemigroups)
Requires:       gap-core >= 4.12.1
Requires:       gap-datastructures >= 0.2.5
Requires:       gap-digraphs >= 1.6.2
Requires:       gap-genss >= 1.6.5
Requires:       gap-images >= 1.3.1
Requires:       gap-io >= 4.5.1
Requires:       gap-orb >= 4.8.2
Suggests:       gap-autodic >= 2020.08.11
Suggests:       gap-gapdoc >= 1.6.3

%description
The Semigroups package is a GAP package containing methods for
semigroups, principally semigroups of transformations, partial
permutations or subsemigroups of regular Rees 0-matrix semigroups.
Semigroups contains more efficient methods than those available in
the GAP library (and in many cases more efficient than any other
software) for creating semigroups, calculating their Green's classes,
size, elements, group of units, minimal ideal, small generating sets,
testing membership, finding the inverses of a regular element,
factorizing elements over the generators, and many more. It is also
possible to test if a semigroup satisfies a particular property, such
as if it is regular, simple, inverse, completely regular, and a
variety of further properties.

%prep
%autosetup -n semigroups-%version

%build
autoreconf -fi
%configure --with-gaproot="%gapdir" --with-external-libsemigroups
%make_build

%install
rm -Rf libsemigroups
%gappkg_simple_install
cd "%buildroot/$fmoddir/"
rm -Rfv Makefile* configure* config.* cnf/ src/ gapbind14/src/ gapbind14/include/ autom4te.cache
find "%buildroot" "(" -name "*.orig" -o -name .gitignore -o \
	-name .dirstamp -o -name .clang-format -o -name .ccls ")" -print -delete
%fdupes %buildroot/%_prefix

%files -f %name.files

%changelog
* Thu Feb 27 2025 Jan Engelhardt <jengelh@inai.de>
- Make specfile conform to POSIX sh
* Sat Feb 22 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.5.0
  * Better inverses
* Sun Oct 20 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.4.0
  * improved IsIsomorphicSemigroup method
  * fixed a ChooseHashFunction rank issue
* Thu May 16 2024 Jan Engelhardt <jengelh@inai.de>
- Remove more build-time files to soothe rpmlint.
- Add no-avx.patch.
* Mon Mar 11 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.7
  * Use MarkAllButFirstSubBags for T_BIPART
* Mon Feb 19 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.6
  * Unspecified changes related to forthcoming changes in the
    GAP core.
* Wed Feb 14 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.5
  * This is a minor release fixing an issue in the kernel extension
    with some further changes for compatibility with GAP, and
    fixing a bug in `IrredundantGeneratingSubset` which gave an
    error for monogenic semigroups.
* Wed Jan 24 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.4
  * Build system updates only
* Fri Jan  5 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.3
  * Update of bundled components (unused in openSUSE)
* Wed Jan  3 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop config.log and autom4te.cache for reproducible builds
* Sun Oct  8 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.2
  * Restore support for GAP workspaces
* Tue Sep 19 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.3.1
  * Improve congruence lattice code
  * Fix some memory leaks
* Sun Mar  5 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.2.1
  * This is a minor release with some changes for compatibility
    with upcoming changes to GAP, and some updates to the build
    system.
* Tue Dec 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.2.0
  * This release contains a number of fixes and improvements, and
    one new feature, which is a method for `IsSelfDualSemigroup`
    and related functionality for semigroups satisfying
    `CanUseFroidurePin`.
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 5.1.0
  * The package now features a compiled C/C++ module which
    interfaces with the libsemigroups C++ library to allow
    high-speed computations for congruences and certain categories
    of semigroup. There are also several new types of semigroup and
    a variety of new methods which can be used with them.
  * The kernel module has been simplified signficantly, to make it
    easier to incorporate future changes in libsemigroups[], and
    some superfluous functionality was withdrawn.
  * The backwards incompatible changes in this release relate to
    matrices over the integers or over a finite field.
* Mon Jun 20 2016 jengelh@inai.de
- Update to new upstream release 2.8.0
  * Added `ApsisMonoid`, `CrossedApsisMonoid`,
  `ModularPartitionMonoid`, `PlanarModularPartitionMonoid`,
  `PlanarPartitionMonoid`, `PlanarUniformBlockBijectionMonoid`,
  `SingularApsisMonoid`, `SingularCrossedApsisMonoid`,
  `SingularModularPartitionMonoid`,
  `SingularPlanarModularPartitionMonoid`,
  `SingularPlanarPartitionMonoid`,
  `SingularPlanarUniformBlockBijectionMonoid`,
  `SingularUniformBlockBijectionMonoid`,
  `UniformBlockBijectionMonoid`
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 2.7.4
  * This is a minor release to fix some manual examples, to correct
  the package url in the `PackageInfo.g` file, and to fix some
  issues with semigroups of bipartitions. It was formerly
  possible to create semigroups of bipartitions where the
  generators had different degrees, but the created semigroups
  were invalid; this is fixed in version 2.7.3.
  * Require GAP 4.8.3 since the function `IsZeroSimpleSemigroup`
  entered an infinite loop for some examples of semigroups of
  partial permutations.
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 2.7.2
  * `IsomorphismReesZeroMatrixSemigroup` is introduced, and it is no
  longer possible to apply `IsomorphismReesMatrixSemigroup` to a
  0-simple semigroup.
  * The meaning of `IsMonoidAsSemigroup` was changed to be consistent
  with the meaning of `IsGroupAsSemigroup`. In earlier versions,
  `IsMonoidAsSemigroup` was `false` for semigroups in the category
  `IsMonoid`.
  * `IsInverseSemigroup` sometimes returned true for semigroups
  which were not inverse
* Sun Feb 22 2015 jengelh@inai.de
- Update to new upstream release 2.2
  * New: the functions SmallestElementSemigroup,
  LargestElementSemigroup, and GeneratorsSmallest.
  * Some minor corrections were made to the methods for creating the
  ideals of some semigroups in standard examples semigroups, such
  as SingularTransformationSemigroup.
* Fri Dec 12 2014 jengelh@inai.de
- Update to new upstream release 2.1.1
  * extensive new features for computing with elements and
  subsemigroups of the partition monoid.
  * support for ideals of transformation, partial permutation, and
  bipartition semigroups, and subsemigroups of Rees 0-matrix
  semigroups.
  * The new operations IsomorphismSemigroups, IsIsomorphicSemigroup,
  and SmallestMultiplicationTable.
  * The new operation MaximalSubsemigroups, which returns the maximal
  subsemigroups of an arbitrary semigroup.
  * The new operation Normalizer for computing a subgroup of a
  permutation group consisting of those permutations that stabilise,
  under conjugation, a transformation, partial perm, or bipartition
  semigroup.
  * The new operation CharacterTableOfInverseSemigroup for finding the
  character table of an inverse semigroup of partial permutations.
  * Methods for defining and manipulating the congruences of a Rees
  0-matrix semigroup.
  * The operation EndomorphismsPartition that returns the monoid
  of endomorphisms preserving a partition. This monoid is defined
  using the minimum possible number of generators.
  * A lot more, see the detailed changelog in the package.
* Tue Feb  4 2014 jengelh@inai.de
- Update to new upstream release 1.4
  * Package rename from citrus to semigroup. The package has been
  completely overhauled, the performance has been improved, and the
  code has been generalized so that in the future the same code can
  be used to compute with other types of semigroups.
  * This release includes several new methods for inverse semigroups
  of partial permutations and for free inverse semigroup. Most
  notably among the new methods for inverse semigroups of partial
  permutations are: "SmallerDegreePartialPermRepresentation" and
  "VagnerPrestonRepresentation" for changing the representation of
  an inverse semigroup of partial permutations.
  * The methods in Semigroups have been extended to apply to
  arbitrary subsemigroups of regular Rees 0-matrix semigroups over
  groups;
  * A new method for MaximalSubsemigroups of Rees matrix semigroup
  has been implemented;
  * The function Read/WriteSemigroups have been renamed
  Read/WriteGenerators and their performance has been improved. It
  is now possible to use WriteGenerators to write to a gzipped file.
* Fri May 10 2013 jengelh@inai.de
- Split citrus (version 0.9999) off the gap RPM package
